Module integrate_tower

Module integrate_tower 

tower integration for OwnedQuery.

Structs

WithQueryLayer
Layer for parsing [OwnedQuery] from a Request and insert into the Request extensions.
WithQueryService
Service for parsing [OwnedQuery] from a Request and insert into the Request extensions.

Type Aliases

QueriesLayerDeprecated
Renamed, use WithQueryLayer instead.
QueriesServcieDeprecated
Renamed, use WithQueryLayer instead.